==> valknut-0.4.4.tar.bz2: valknut-0.4.4/valknut/dcchat.h <==
/***************************************************************************
                          dcchat.h  -  description
                             -------------------
    begin                : Don Mr 28 2002
    copyright            : (C) 2002 by Mathias Kster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DCCHAT_H
#define DCCHAT_H

/**
  *@author Mathias Kster
  */

#include <qwidget.h>
#include <qimage.h>
//Added by qt3to4:
#include <QEvent>
#include <QLabel>
#include <QList>

/* for enum eSecureState */
#include <dclib/core/types.h>

/* TODO re-write chat history to use QStringList */
#include <dclib/core/clist.h>
#include <dclib/core/cstring.h>

#include "DCDialogChat.h"

class DCQTextEdit;
class DCClient;
class QStatusBar;
class DCShellCommandRunner;
class CMessagePrivateChat;

class DCChat : public QWidget, public Ui::DCDialogChat {
Q_OBJECT

public: 
	/** construtor */
	DCChat( QWidget * parent, DCClient * client, bool bprivate = TRUE );
	/** destructor */
	virtual ~DCChat();

	/** */
	void InitDocument();
	/** */
	DCClient * GetClient() { return m_pClient; };
	/** */
	void SetNick( QString nick, QString hubname );
	/** */
	QString GetNick() { return m_sNick; };
	/** */
	void AddMessage( QString nick, QString message, bool bremote = TRUE, bool forward = FALSE );
	/** */
	void AddMessage( CMessagePrivateChat * msg, bool bremote = TRUE, bool forward = FALSE );
	/** show statusmessage, if show true the settings are ignored */
	void AddStatus( QString message, bool show = FALSE );
	/** */
	void SetCrypt( eSecureState e );

	/** */
	bool close();
	/** */
	void InitView();
	/** Made public for auto responder */
	void SendMessage( QString message = "" );

protected:
	/** event filter */
	virtual bool eventFilter( QObject * object, QEvent * event );

private:
	/** */
	bool CheckForCommand();
	/** */
	bool CheckForData( QString message );
	/** */
	void NickCompletion();
	/** */
	void QT3TranslationSync();

	/** */
	QString GetTimeStamp();
	/** */
	void AddOutput( QString message );
	/** */
	int FindFirstLink( QString msg );
	/** */
	int ConvertLinks( QString msg, QString & s );
	/** */
	int FindFirstEmoticon( QString msg );
	/** */
	int ConvertEmoticons( QString msg, QString & s );

	/** */
	void AddHistory( CString message );

	/** */
	DCQTextEdit * m_pTextEdit_CHATOUTPUT;
	/** */
	QString m_sLanguage;
	/** */
	bool m_bPrivateChat;
	/** */
	bool m_bSendAway;
	/** */
	DCClient * m_pClient;
	/** */
	QString m_sNick;
	/** */
	QStatusBar * m_pStatusBar;
	/** */
	QLabel * m_pStatusCrypt;
	/** */
	eSecureState m_eSecureState;
	/** */
	CList<CString> m_History;
	/** last line */
	CString m_sHistoryTempString;
	/** cursor pos */
	int m_nHistoryTempPara;
	/** cursor pos */
	int m_nHistoryTempIndex;
	/** */
	CString * m_pCurrentHistory;
	/** */
	QString m_sTimeStamp;
	/** */
	int m_nTabStart;
	/** */
	int m_nTabEnd;
	/** */
	int m_nTabPressed;
	/** */
	QString m_sTabSaved;
	/** */
	QString m_sTabNick;
	/** */
	QWidget * m_pParent;
	/** */
	QString m_sLabel;
	/** */
	bool m_bFirstInit;
	/** List of running shell command threads */
	QList<DCShellCommandRunner*> * m_pShellRunners;
	
public slots:
	/** */
	void slotRightButtonClickedChatOutput( const QPoint& );

private slots:
	/** */
	void slotClickedChatOutput();
	/** */
	void slotDoubleClickedChatOutput();
	/** */
	void slotTextChangedChatInput();
	/** */
	void slotSendMessage();
	/** */
	void slotShellCommandFinished( bool ok, QString output );
	/** */
	void slotLoadEmoticons();
};

#endif

==> valknut-0.4.5.tar.bz2: valknut-0.4.5/valknut/dcchat.h <==
/***************************************************************************
                          dcchat.h  -  description
                             -------------------
    begin                : Don Mr 28 2002
    copyright            : (C) 2002 by Mathias Kster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DCCHAT_H
#define DCCHAT_H

/**
  *@author Mathias Kster
  */

#include <qwidget.h>
#include <qimage.h>
//Added by qt3to4:
#include <QEvent>
#include <QLabel>
#include <QList>
#include <QStringList>

/* for enum eSecureState */
#include <dclib/core/types.h>

#include "DCDialogChat.h"

class DCQTextEdit;
class DCClient;
class QStatusBar;
class DCShellCommandRunner;
class CMessagePrivateChat;

class DCChat : public QWidget, public Ui::DCDialogChat {
Q_OBJECT

public: 
	/** construtor */
	DCChat( QWidget * parent, DCClient * client, bool bprivate = true );
	/** destructor */
	virtual ~DCChat();

	/** */
	void InitDocument();
	/** */
	DCClient * GetClient() { return m_pClient; };
	/** */
	void SetNick( QString nick, QString hubname );
	/** */
	QString GetNick() { return m_sNick; };
	/** */
	void AddMessage( QString nick, QString message, bool bremote = true, bool forward = false );
	/** */
	void AddMessage( CMessagePrivateChat * msg, bool bremote = true, bool forward = false );
	/** show statusmessage, if show true the settings are ignored */
	void AddStatus( QString message, bool show = false );
	/** */
	void SetCrypt( eSecureState e );

	/** */
	bool close();
	/** */
	void InitView();
	/** Made public for auto responder */
	void SendMessage( QString message = "" );

protected:
	/** event filter */
	virtual bool eventFilter( QObject * object, QEvent * event );

private:
	/** */
	bool CheckForCommand();
	/** */
	bool CheckForData( QString message );
	/** */
	void NickCompletion();
	/** */
	void QT3TranslationSync();

	/** */
	QString GetTimeStamp();
	/** */
	void AddOutput( QString message );
	/** */
	int FindFirstLink( QString msg );
	/** */
	int ConvertLinks( QString msg, QString & s );
	/** */
	int FindFirstEmoticon( QString msg );
	/** */
	int ConvertEmoticons( QString msg, QString & s );

	/** */
	void AddHistory( QString message );

	/** */
	DCQTextEdit * m_pTextEdit_CHATOUTPUT;
	/** */
	QString m_sLanguage;
	/** */
	bool m_bPrivateChat;
	/** */
	bool m_bSendAway;
	/** */
	DCClient * m_pClient;
	/** */
	QString m_sNick;
	/** */
	QStatusBar * m_pStatusBar;
	/** */
	QLabel * m_pStatusCrypt;
	/** */
	eSecureState m_eSecureState;
	/** */
	QStringList m_lHistory;
	/** last line */
	QString m_sHistoryTempString;
	/** cursor pos */
	/* int m_nHistoryTempPara; */
	/** cursor pos */
	int m_nHistoryTempIndex;
	/** */
	int m_nCurrentHistoryIndex;
	/** */
	QString m_sTimeStamp;
	/** */
	int m_nTabStart;
	/** */
	int m_nTabEnd;
	/** */
	int m_nTabPressed;
	/** */
	QString m_sTabSaved;
	/** */
	QString m_sTabNick;
	/** */
	QWidget * m_pParent;
	/** */
	QString m_sLabel;
	/** */
	bool m_bFirstInit;
	/** List of running shell command threads */
	QList<DCShellCommandRunner*> * m_pShellRunners;
	
public slots:
	/** */
	void slotRightButtonClickedChatOutput( const QPoint& );

private slots:
	/** */
	void slotClickedChatOutput();
	/** */
	void slotDoubleClickedChatOutput();
	/** */
	void slotTextChangedChatInput();
	/** */
	void slotSendMessage();
	/** */
	void slotShellCommandFinished( bool ok, QString output );
	/** */
	void slotLoadEmoticons();
	/** */
	void slotBGColorChanged();
};

#endif
